@@ -11,7 +11,7 @@ sub get {
 			iso_code => 'en',
 			coding  => 'ASCII',
 			purpose => 'embedded emergency localisation',
-			version => $VERSION,
+			version => $Kephra::VERSION,
 		},
 		app => {
 			general => {
@@ -486,7 +486,9 @@ sub get {
 					'tabbar-contexmenu' => 'Tabbar',
 					toolbar => 'Main Toolbar',
 					webpage => {
+						'bug-tracker' => 'Bug Tracker',
 						documentation => 'Online Docs',
+						'feature-wish' => 'Feature Wish',
 						forum => 'Perl Forum',
 					},
 					'window-stay-on-top' => 'Stay On Top',
@@ -942,7 +944,9 @@ sub get {
 					'tabbar-contexmenu' => 'enable or disable context menus on tabbar',
 					toolbar => 'switch visibility of the main toolbar',
 					webpage => {
+						'bug-tracker' => 'please report any problem with the programm',
 						documentation => 'open online documentation with your default browser',
+						'feature-wish' => 'report a feature or design change wish',
 						forum => 'go to a perl web forum based on current language setting',
 					},
 					window => {
